Console.Clear();

RenderXML( Document.Text );

function RenderXML( text )
{
	var xmldoc = new ActiveXObject("Microsoft.XMLDOM");
	xmldoc.async = false;
	xmldoc.loadXML( text );
	if( xmldoc.parseError.errorCode != 0 )
	{
		ReportParseError(xmldoc.parseError);
		return;
	}

	var styleSheetUrl = GetStyleSheet( xmldoc );
	if( styleSheetUrl == null )
	{
		Console.WriteLine( "No xsl-stylesheet processing instruction found." );
		return;
	}

	// construct the full path to the style sheet
	if( -1 == styleSheetUrl.indexOf(":") )
		styleSheetUrl = Document.Path + styleSheetUrl;
	
	Console.WriteLine( "Applying xsl-stylesheet " + styleSheetUrl );

	var style = new ActiveXObject("Microsoft.XMLDOM");
	style.async = false;
	style.load( styleSheetUrl );
	if (style.parseError.errorCode != 0)
	{
		ReportParseError(style.parseError);
		return;
	}
	
	var result;
	try
	{
		result = xmldoc.transformNode(style);
	}
	catch( exception )
	{
		Console.WriteLineColor( "XSL Runtime Error: " + exception.description, 255 );
		return;
	}
  	
	var newDoc = Application.Documents.Add();
	newDoc.Text = result;
	newDoc.Title = "Rendered " + Document.Title;
}

function GetStyleSheet( xmldoc )
{
	var nodeList = xmldoc.childNodes;
	var styleSheetUrl;
	for( var i=0; i<nodeList.length; i++ )
	{
		var node = nodeList(i);
		if( node.nodeType != 7 )
			continue;
			
		if( node.nodeName != 'xml-stylesheet' )
			continue;
	
		if( !RegExp( "type\s*\=\"(.*?)\"" ).test(node.data) )
			continue;
			
		if( RegExp.$1 != "text/xsl" )
			continue;
			
		if( !RegExp( "href\s*\=\"(.*?)\"" ).test(node.data) )
			continue;
	
		return RegExp.$1;
	}
	
	return null;
}

function ReportParseError( error )
{
	Console.WriteLineColor( "XML Error loading '" +  error.url + "': " + error.reason, 255 );
	if( error.line > 0 )
	{
		var s = "";
		for (var i=1; i<error.linepos; i++) 
			s += " ";

		Console.WriteLine( "at line " + error.line + 
			", character " + error.linepos +
			"\n" + error.srcText + "\n" + s + "^" );
	}
}
